# -*- coding: utf-8 -*-
try:
    from json import dumps
except ImportError:
    from simplejson import dumps

from flask import Response
from functools import wraps, partial


def jsonify(method=None, cls=None):

    if method is None:
        return partial(jsonify, cls=cls)

    @wraps(method)
    def inner(*args, **kwargs):
        retval = method(*args, **kwargs)

        # if the user is trying to return an error, we want to preserve
        # the error code in the HTTP response, but still send the intended data
        response_obj = retval
        if isinstance(retval, JSONStatusResponse):
            response_obj = retval.body

        if cls is not None:
            response = Response(dumps(response_obj, cls=cls), mimetype='application/json')
        else:
            response = Response(dumps(response_obj), mimetype='application/json')

        # if the user is trying to return an error, we need to manually
        # set the error code
        if isinstance(retval, JSONStatusResponse):
            response.status_code = retval.status_code

        return response

    return inner


class JSONStatusResponse(object):

    def __init__(self, status_code=200, body={}):
        self.status_code = status_code
        self.body = body;


"""
flask-jsonify
-------------

Description goes here...

Links
`````

* `documentation <http://github.com/fredj/flask-jsonify/raw/master/README>`_

"""
from setuptools import setup


setup(
    name='flask-jsonify-emidln',
    version='0.1',
    url='http://github.com/emidln/flask-jsonify',
    license='BSD',
    author='Frederic Junod',
    author_email='frederic.junod@gmail.com',
    description='A small Flask decorator for returning json. This is a fork pushed to PyPI for easy install.',
    long_description=__doc__,
    packages=['flaskext'],
    namespace_packages=['flaskext'],
    zip_safe=False,
    platforms='any',
    install_requires=[
        'Flask',
        'simplejson' # FIXME: only for python < 2.6
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)
